@@ -35,12 +35,12 @@ class SummaryStatistic
 
    // Virtual methods
    virtual void calculate(const Forest &forest) =0;
-   virtual void printLocusOutput(std::ostream &output) const =0;
    virtual void clear() =0;
    virtual SummaryStatistic* clone() const =0; 
 
    // Optional methods
-   virtual void printSegmentOutput(std::ostream &output) const { };
+   virtual void printLocusOutput(std::ostream &output) const { (void) output; };
+   virtual void printSegmentOutput(std::ostream &output) const { (void) output; };
 };
 
 #endif
