@@ -39,12 +39,15 @@ echo "Testing Initial Tree"
  test_scrm 3 100 -t 5 -L -oSFS -transpose-segsites || exit 1
  test_scrm 50 20 -O || exit 1
  test_scrm 25 1 -T || exit 1
+ test_scrm 10 5 -I 1 5 -eI 1.0 5 -L || exit 1
+ test_scrm 10 5 -I 2 2 2 0.5 -eI 1.0 3 3 -L || exit 1
 echo ""
 
 echo "Testing Recombinations"
- test_scrm 4 10 -r 5 100 || exit 1
- test_scrm 6 10 -r 1 100 -t 5 -L -T -transpose-segsites || exit 1
- test_scrm 8 10 -r 1 100 -t 5 -oSFS -O || exit 1
+ test_scrm 4 10 -r 5 100 -l -1 || exit 1
+ test_scrm 6 10 -r 1 100 -t 5 -L -T -transpose-segsites -l -1 || exit 1
+ test_scrm 8 10 -r 1 100 -t 5 -oSFS -O -l -1 || exit 1
+ test_scrm 10 5 -r 5 100 -I 2 2 2 0.5 -eI 1.0 3 3 -L -l -1 || exit 1
 echo ""
 
 echo "Testing Pruning"
@@ -52,6 +55,7 @@ echo "Testing Pruning"
  test_scrm 3 50 -r 10 500 -l 0 -t 1 -oSFS || exit 1
  test_scrm 10 20 -r 10 500 -l 2r -L || exit 1
  test_scrm 10 20 -r 1 500 -l -1 -T || exit 1
+ test_scrm 10 5 -r 5 100 -I 2 2 2 0.5 -eI 1.0 3 3 -L -l 2r || exit 1
 echo ""
 
 echo "Testing Migration"
@@ -88,5 +92,6 @@ echo ""
 echo "Various Edge Cases"
  test_scrm 6 1 -I 2 3 3 0.5 -r 1 100 -es 0 2 0.5 -ej 1 3 1 -t 1  || exit 1
  test_scrm 10 1 -es 1.0 1 0.5 -ej 1.0 2 1 || exit 1
+ test_scrm 4 1 -t 1.0 -I 2 2 0 -ej 1.0 1 2 -eI 3.5 0 2 || exit 1
 echo ""
 
